# Core examples

This directory contains examples related to the `bilby.core` modules of
`bilby`. Examples are intended to be a starting point, showing different
functionality which you can extend. They are not exhaustive.
